==> 1.0.0.tar.gz: lib/src/video_shopping.dart <==
import 'models/add_to_cart_result.dart';
import 'models/fw_events.dart';
import 'models/fw_method_name.dart';
import 'models/product.dart';
import 'models/product_info_view_configuration.dart';
import 'utils/fw_logger_util.dart';
import 'utils/fw_method_channel_util.dart';
import 'utils/model_utils/add_to_cart_result_util.dart';
import 'utils/model_utils/fw_events_util.dart';
import 'utils/model_utils/fw_method_name_util.dart';
import 'utils/model_utils/product_info_view_configuration_util.dart';
import 'utils/model_utils/product_util.dart';

typedef AddToCartCallback = Future<AddToCartResult> Function(
    AddToCartEvent? event);
typedef UpdateProductDetailsCallback = Future<List<Product>?> Function(
    UpdateProductDetailsEvent? event);
typedef WillDisplayProductCallback = Future<ProductInfoViewConfiguration?>
    Function(WillDisplayProductEvent? event);

/// The entry class of video shopping.
class VideoShopping {
  static VideoShopping? _instance;

  /// Defaults to true. You can hide the cart icon by setting this property to false.
  bool get cartIconVisible => _cartIconVisible;
  set cartIconVisible(bool newValue) {
    _cartIconVisible = newValue;
    final nativeMethodName = FWShoppingMethodNameUtil.convertToNativeMethod(
      FWShoppingNativeMethodName.setCartIconVisible,
    );
    FWMethodChannelUtil.getShoppingChannel().invokeMethod(
      nativeMethodName,
      newValue,
    );
  }

  bool _cartIconVisible = true;

  /// This callback is triggered when the user clicks the "Add to cart" button.
  ///
  /// The host app can return an [AddToCartResult] object to tell FireworkSDK the result of adding to cart.
  AddToCartCallback? onAddToCart;

  /// This callback is triggered when the video will be shown.
  ///
  /// The host app can return a [Product] list to update the latest product information.
  UpdateProductDetailsCallback? onUpdateProductDetails;

  /// This callback is triggered when the product will be shown.
  ///
  /// The host app can return a [ProductInfoViewConfiguration] object to configure "Add to cart" button style and cart icon style.
  WillDisplayProductCallback? onWillDisplayProduct;

  static VideoShopping _getInstance() {
    _instance ??= VideoShopping._();
    return _instance!;
  }

  VideoShopping._() {
    FWMethodChannelUtil.getShoppingChannel().setMethodCallHandler((call) async {
      final fwMethod = FWShoppingMethodNameUtil.createMethodName(call.method);
      if (fwMethod == null) {
        return null;
      }

      switch (fwMethod) {
        case FWShoppingMethodName.addToCart:
          final addToCartEvent = AddToCartEventUtil.fromJson(call.arguments);
          if (onAddToCart != null) {
            final result = await onAddToCart!.call(addToCartEvent);
            final resultJson = AddToCartResultUtil.toJson(result);
            FWLoggerUtil.log("onAddToCart resultJson $resultJson");
            return resultJson;
          }
          break;
        case FWShoppingMethodName.updateProductDetails:
          final updateProductDetailsEvent =
              UpdateProductDetailsEventUtil.fromJson(call.arguments);
          final productList =
              await onUpdateProductDetails?.call(updateProductDetailsEvent);
          if (productList != null) {
            final productJsonList = productList
                .map(
                  (product) => ProductUtil.toJson(product),
                )
                .toList();
            FWLoggerUtil.log(
                "onUpdateProductDetails productJsonList $productJsonList");
            return productJsonList;
          }
          break;
        case FWShoppingMethodName.willDisplayProduct:
          final willDisplayProductEvent =
              WillDisplayProductEventUtil.fromJson(call.arguments);
          if (onWillDisplayProduct != null) {
            final config =
                await onWillDisplayProduct!.call(willDisplayProductEvent);
            if (config != null) {
              final configJson =
                  ProductInfoViewConfigurationUtil.toJson(config);
              FWLoggerUtil.log("onWillDisplayProduct configJson $configJson");
              return configJson;
            } else {
              FWLoggerUtil.log("onWillDisplayProduct empty config");
              return {};
            }
          }
          break;
      }

      return null;
    });
  }

  factory VideoShopping.getInstance() => _getInstance();

  /// Sets cart item [count].
  void setCartItemCount(int count) {
    final nativeMethodName = FWShoppingMethodNameUtil.convertToNativeMethod(
      FWShoppingNativeMethodName.setCartItemCount,
    );
    FWMethodChannelUtil.getShoppingChannel().invokeMethod(
      nativeMethodName,
      count,
    );
  }

  /// Exits cart page.
  void exitCartPage() {
    final nativeMethodName = FWShoppingMethodNameUtil.convertToNativeMethod(
      FWShoppingNativeMethodName.exitCartPage,
    );
    FWMethodChannelUtil.getShoppingChannel().invokeMethod(
      nativeMethodName,
    );
  }
}

==> 1.3.0.tar.gz: lib/src/video_shopping.dart <==
import 'models/add_to_cart_result.dart';
import 'models/fw_events.dart';
import 'models/fw_method_name.dart';
import 'models/product.dart';
import 'models/product_info_view_configuration.dart';
import 'utils/fw_method_channel_util.dart';
import 'utils/model_utils/add_to_cart_result_util.dart';
import 'utils/model_utils/fw_events_util.dart';
import 'utils/model_utils/fw_method_name_util.dart';
import 'utils/model_utils/product_info_view_configuration_util.dart';
import 'utils/model_utils/product_util.dart';

typedef AddToCartCallback = Future<AddToCartResult> Function(
    AddToCartEvent? event);
typedef CustomClickCartIconCallback = Future<void> Function();
typedef UpdateProductDetailsCallback = Future<List<Product>?> Function(
    UpdateProductDetailsEvent? event);
typedef WillDisplayProductCallback = Future<ProductInfoViewConfiguration?>
    Function(WillDisplayProductEvent? event);

/// The entry class of video shopping.
class VideoShopping {
  static VideoShopping? _instance;

  /// Defaults to true. You can hide the cart icon by setting this property to false.
  bool get cartIconVisible => _cartIconVisible;
  set cartIconVisible(bool cartIconVisible) {
    _cartIconVisible = cartIconVisible;
    final nativeMethodName = FWShoppingMethodNameUtil.convertToNativeMethod(
      FWShoppingNativeMethodName.setCartIconVisible,
    );
    FWMethodChannelUtil.getShoppingChannel().invokeMethod(
      nativeMethodName,
      cartIconVisible,
    );
  }

  bool _cartIconVisible = true;

  /// This callback is triggered when the user clicks the "Add to cart" button.
  ///
  /// The host app can return an [AddToCartResult] object to tell FireworkSDK the result of adding to cart.
  AddToCartCallback? onAddToCart;

  /// This callback is triggered when the user clicks the shopping cart icon.
  ///
  /// The host app can customize the processing logic of clicking the shopping cart icon by setting the callback.
  /// In the callack, you could call FireworkSDK.getInstance().navigator.popNativeContainer to close the player
  /// and call navigation.navigate to push the RN cart page.
  /// Currently, there is be a limitation on the iOS side when you set the callback.
  /// That is, if you set the callback, you need to call FireworkSDK.getInstance().navigator.popNativeContainer in the callback.
  /// Otherwise there will be bugs on the iOS side.
  CustomClickCartIconCallback? get onCustomClickCartIcon =>
      _onCustomClickCartIcon;
  set onCustomClickCartIcon(
      CustomClickCartIconCallback? onCustomClickCartIcon) {
    _onCustomClickCartIcon = onCustomClickCartIcon;
    final nativeMethodName = FWShoppingMethodNameUtil.convertToNativeMethod(
      FWShoppingNativeMethodName.setCustomClickCartIconEnabled,
    );
    FWMethodChannelUtil.getShoppingChannel().invokeMethod(
      nativeMethodName,
      onCustomClickCartIcon != null,
    );
  }

  CustomClickCartIconCallback? _onCustomClickCartIcon;

  /// This callback is triggered when the video will be shown.
  ///
  /// The host app can return a [Product] list to update the latest product information.
  UpdateProductDetailsCallback? onUpdateProductDetails;

  /// This callback is triggered when the product will be shown.
  ///
  /// The host app can return a [ProductInfoViewConfiguration] object to configure "Add to cart" button style and cart icon style.
  WillDisplayProductCallback? onWillDisplayProduct;

  static VideoShopping _getInstance() {
    _instance ??= VideoShopping._();
    return _instance!;
  }

  VideoShopping._() {
    FWMethodChannelUtil.getShoppingChannel().setMethodCallHandler((call) async {
      final fwMethod = FWShoppingMethodNameUtil.createMethodName(call.method);
      if (fwMethod == null) {
        return null;
      }

      switch (fwMethod) {
        case FWShoppingMethodName.addToCart:
          final addToCartEvent = AddToCartEventUtil.fromJson(call.arguments);
          if (onAddToCart != null) {
            final result = await onAddToCart!.call(addToCartEvent);
            final resultJson = AddToCartResultUtil.toJson(result);
            return resultJson;
          }
          break;
        case FWShoppingMethodName.updateProductDetails:
          final updateProductDetailsEvent =
              UpdateProductDetailsEventUtil.fromJson(call.arguments);
          final productList =
              await onUpdateProductDetails?.call(updateProductDetailsEvent);
          if (productList != null) {
            final productJsonList = productList
                .map(
                  (product) => ProductUtil.toJson(product),
                )
                .toList();
            return productJsonList;
          }
          break;
        case FWShoppingMethodName.willDisplayProduct:
          final willDisplayProductEvent =
              WillDisplayProductEventUtil.fromJson(call.arguments);
          if (onWillDisplayProduct != null) {
            final config =
                await onWillDisplayProduct!.call(willDisplayProductEvent);
            if (config != null) {
              final configJson =
                  ProductInfoViewConfigurationUtil.toJson(config);
              return configJson;
            } else {
              return {};
            }
          }
          break;
        case FWShoppingMethodName.clickCartIcon:
          if (onCustomClickCartIcon != null) {
            await onCustomClickCartIcon!.call();
          }
          break;
      }

      return null;
    });
  }

  factory VideoShopping.getInstance() => _getInstance();

  /// Sets cart item [count].
  void setCartItemCount(int count) {
    final nativeMethodName = FWShoppingMethodNameUtil.convertToNativeMethod(
      FWShoppingNativeMethodName.setCartItemCount,
    );
    FWMethodChannelUtil.getShoppingChannel().invokeMethod(
      nativeMethodName,
      count,
    );
  }
}
